%
%   Step_1_obtain_raw_monthly_data.m
%
%  This is step 1 of 3 of the creation of working file from raw data.
%
%  input Excel file: "raw monthly data.xls"
%  output Matlab data: "temporary_data.mat"
%
%  user-defined function: "merge_fh.m"
%  
%
%  February 2014
%  
%%

clear;clc;


disp('********************** program starts ************************');

% Define overall year-month
first_yr=1970;
last_yr=2013;
yr_month_all=[];
for year=first_yr:last_yr;
    for month=1:12;
        yr_month_all=cat(1,yr_month_all,year*100+month);
    end;
end;


% import data
infile='raw monthly data';
z=xlsread(infile,'data','a3:i528');



% add NaNs for recent missing values
z=merge_fh(yr_month_all,z);
    % column 2 and 3 are merge flags

    
% give variable names
yr_month=z(:,1);
r_bar=z(:,4);
collateralized_r_BOJ=z(:,5);
M=z(:,6);
M_req=z(:,7);
base=z(:,8);
core_CPI_NSA=z(:,9);
core_core_CPI_NSA=z(:,10);
core_core_CPI_SA=z(:,11);
clear z;


% Adjustment for consumption tax hikes of April 1989 and April 1997
ctax_1989=1.2;  % adjustment on the April 1989 hike is 1.2 percent per year
ctax_1997=1.5;  % adjustment on the April 1997 hike is 1.5 percent per year
pai_12=log(core_CPI_NSA(13:end))-log(core_CPI_NSA(1:end-12));
pai_12=cat(1,NaN(12,1),pai_12);
% adjust for the April 1989 consumption tax hike
pai_12=pai_12-(yr_month>=198904 & yr_month<=199003)*ctax_1989/100;
% adjust for the April 1989 consumption tax hike
pai_12=pai_12-(yr_month>=199704 & yr_month<=199803)*ctax_1997/100;
% back out implied level
temp=log(core_CPI_NSA);
for t=13:numel(yr_month);
    temp(t)=temp(t-12)+pai_12(t);
end;
core_CPI_NSA_ctax=exp(temp);



% save as ".mat" file
save('temporary_data',...
    'yr_month','r_bar','collateralized_r_BOJ',...
    'M','M_req','base',...
    'core_core_CPI_SA','core_CPI_NSA_ctax',...
    'core_CPI_NSA','core_core_CPI_NSA'...
);
whos -file temporary_data
